@@ -284,8 +284,8 @@ combo_box_set_active_text (GtkComboBox *combo,
 		g_signal_handler_block (G_OBJECT (combo), handler_id);
 		prelight_handler_id = 0;
 		if (ABI_IS_FONT_COMBO (combo)) {
-				prelight_handler_id = * (gulong *) g_object_get_data (G_OBJECT (combo), PROP_HANDLER_ID);
-				g_signal_handler_block (G_OBJECT (combo), prelight_handler_id);
+			prelight_handler_id = GPOINTER_TO_UINT(g_object_get_data (G_OBJECT (combo), PROP_HANDLER_ID));
+			g_signal_handler_block (G_OBJECT (combo), prelight_handler_id);
 		}
 
 		gtk_combo_box_set_active_iter (combo, &iter);
@@ -298,7 +298,7 @@ combo_box_set_active_text (GtkComboBox *combo,
 	else if (ABI_IS_FONT_COMBO (combo)) {
 		// special case font combo, non existant entries are added
 		g_signal_handler_block (G_OBJECT (combo), handler_id);
-		prelight_handler_id = * (gulong *) g_object_get_data (G_OBJECT (combo), PROP_HANDLER_ID);
+		prelight_handler_id = GPOINTER_TO_UINT(g_object_get_data (G_OBJECT (combo), PROP_HANDLER_ID));
 		g_signal_handler_block (G_OBJECT (combo), prelight_handler_id);
 
 		abi_font_combo_insert_font (ABI_FONT_COMBO (combo), text, TRUE);
@@ -332,7 +332,7 @@ public:									// we create...
 		// map the user_data into an object and dispatch the event.
 	
 		_wd * wd = static_cast<_wd *>(user_data);
-		UT_ASSERT(wd);
+		UT_return_if_fail(wd);
 		GdkEvent * event = gtk_get_current_event();
 		wd->m_pUnixToolbar->setCurrentEvent(event);
 		if (!wd->m_blockSignal)
@@ -347,7 +347,7 @@ public:									// we create...
 		// map the user_data into an object and dispatch the event.
 	
 		_wd * wd = reinterpret_cast<_wd *>(user_data);
-		UT_ASSERT(wd);
+		UT_return_if_fail(wd);
 		GdkEvent * event = gtk_get_current_event();
 		wd->m_pUnixToolbar->setCurrentEvent(event);
 		if (!wd->m_blockSignal && (rows > 0) && (cols > 0))
@@ -456,7 +456,7 @@ public:									// we create...
 
 	static void s_combo_changed(GtkComboBox * combo, _wd * wd)
 	{
-		UT_ASSERT(wd);
+		UT_return_if_fail(wd);
 
 		// only act if the widget has been shown and embedded in the toolbar
 		if (!wd->m_widget || wd->m_blockSignal) {
@@ -555,7 +555,7 @@ static void s_proxy_activated(GtkAction * action, _wd * wd)
 		const gchar * editMethod = gtk_action_get_name(action);
 		XAP_UnixApp * pUnixApp = wd->m_pUnixToolbar->getApp();
 		const EV_EditMethodContainer * pEMC = pUnixApp->getEditMethodContainer();
-		UT_ASSERT(pEMC);
+		UT_return_if_fail(pEMC);
 		EV_EditMethod * pEM = NULL;
 
 		AV_View * pView = wd->m_pUnixToolbar->getFrame()->getCurrentView();
@@ -585,6 +585,9 @@ EV_UnixToolbar::EV_UnixToolbar(XAP_UnixApp 	*pUnixApp,
 EV_UnixToolbar::~EV_UnixToolbar(void)
 {
 	UT_VECTOR_PURGEALL(_wd *,m_vecToolbarWidgets);
+	if(m_wVSizeGroup) {
+		g_object_unref(m_wVSizeGroup);
+	}
 	_releaseListener();
 }
 
@@ -605,7 +608,7 @@ bool EV_UnixToolbar::toolbarEvent(_wd 				* wd,
 	XAP_Toolbar_Id id = wd->m_id;
 
 	const EV_Toolbar_ActionSet * pToolbarActionSet = m_pUnixApp->getToolbarActionSet();
-	UT_ASSERT(pToolbarActionSet);
+	UT_return_val_if_fail(pToolbarActionSet, false);
 
 	const EV_Toolbar_Action * pAction = pToolbarActionSet->getAction(id);
 	UT_ASSERT(pAction);
@@ -642,7 +645,7 @@ bool EV_UnixToolbar::toolbarEvent(_wd 				* wd,
 		return false;
 
 	const EV_EditMethodContainer * pEMC = m_pUnixApp->getEditMethodContainer();
-	UT_ASSERT(pEMC);
+	UT_return_val_if_fail(pEMC, false);
 
 	EV_EditMethod * pEM = pEMC->findEditMethodByName(szMethodName);
 	UT_ASSERT(pEM);						// make sure it's bound to something
@@ -787,6 +790,7 @@ bool EV_UnixToolbar::synthesize(void)
 
 	//m_wHSizeGroup = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
 	m_wVSizeGroup = gtk_size_group_new(GTK_SIZE_GROUP_VERTICAL);
+	g_object_ref(m_wVSizeGroup);
 
 #if defined(EMBEDDED_TARGET) && EMBEDDED_TARGET == EMBEDDED_TARGET_HILDON
 #else
@@ -802,7 +806,7 @@ bool EV_UnixToolbar::synthesize(void)
 	for (UT_uint32 k=0; (k < nrLabelItemsInLayout); k++)
 	{
 		EV_Toolbar_LayoutItem * pLayoutItem = m_pToolbarLayout->getLayoutItem(k);
-		UT_ASSERT(pLayoutItem);
+		UT_continue_if_fail(pLayoutItem);
 
 		XAP_Toolbar_Id id = pLayoutItem->getToolbarId();
 		EV_Toolbar_Action * pAction = pToolbarActionSet->getAction(id);
@@ -870,7 +874,10 @@ bool EV_UnixToolbar::synthesize(void)
 				gtk_drag_source_set(wwd,GDK_BUTTON3_MASK,
 									s_AbiTBTargets,1,
 									GDK_ACTION_COPY);
-				setDragIcon(wwd, (GtkImage*)gtk_image_new_from_stock(ABIWORD_INSERT_TABLE, GTK_ICON_SIZE_DND));
+				GtkImage * dragimage = (GtkImage*)gtk_image_new_from_stock(ABIWORD_INSERT_TABLE, GTK_ICON_SIZE_DND);
+				g_object_ref_sink(dragimage);
+				setDragIcon(wwd, dragimage);  // does not take ownership
+				g_object_unref(dragimage);
 				gtk_drag_dest_set(wwd, GTK_DEST_DEFAULT_ALL,
 									s_AbiTBTargets,1,
 									GDK_ACTION_COPY);
@@ -887,16 +894,6 @@ bool EV_UnixToolbar::synthesize(void)
 					UT_ASSERT(g_ascii_strcasecmp(pLabel->getIconName(),"NoIcon")!=0);
 
 					gboolean show = TRUE;
-					if (0 == strncmp("ALIGN_RIGHT", pLabel->getIconName(), strlen("ALIGN_RIGHT")) && 
-						GTK_TEXT_DIR_RTL != gtk_widget_get_direction(m_wToolbar)) {
-						/* only show in rtl mode */
-						show = FALSE;
-					}
-					else if (0 == strncmp("ALIGN_LEFT", pLabel->getIconName(), strlen("ALIGN_LEFT")) && 
-						GTK_TEXT_DIR_RTL == gtk_widget_get_direction(m_wToolbar)) {
-						/* only show in ltr mode */
-						show = FALSE;
-					}
 					wd->m_widget = toolbar_append_toggle (GTK_TOOLBAR (m_wToolbar), pLabel->getIconName(),
 												    	  pLabel->getToolbarLabel(), NULL, 
 														  (GCallback) _wd::s_callback, (gpointer) wd, 
@@ -912,7 +909,10 @@ bool EV_UnixToolbar::synthesize(void)
 									s_AbiTBTargets,1,
 									GDK_ACTION_COPY);
 				gchar *stock_id = abi_stock_from_toolbar_id(pLabel->getIconName());
-				setDragIcon(wwd, (GtkImage*)gtk_image_new_from_stock(stock_id, GTK_ICON_SIZE_DND));
+				GtkImage *dragimage = (GtkImage*)gtk_image_new_from_stock(stock_id, GTK_ICON_SIZE_DND);
+				g_object_ref_sink(dragimage);
+				setDragIcon(wwd, dragimage); // does not take dragimage ownership
+				g_object_unref(dragimage);
 				g_free (stock_id);
 				stock_id = NULL;
 				gtk_drag_dest_set(wwd,static_cast<GtkDestDefaults>(GTK_DEST_DEFAULT_ALL),
@@ -948,10 +948,10 @@ bool EV_UnixToolbar::synthesize(void)
 					proxy_action_name = "dlgFont";
 				}
 				else if (wd->m_id == AP_TOOLBAR_ID_FMT_FONT) {
-					gulong *handler_id = new gulong;
+					gulong handler_id;
 					combo = abi_font_combo_new ();
 					gtk_widget_set_name (combo, "AbiFontCombo");
-					*handler_id = g_signal_connect (G_OBJECT(combo), "prelight", 
+					handler_id = g_signal_connect (G_OBJECT(combo), "prelight", 
 												    G_CALLBACK(_wd::s_font_prelight), 
 												    wd);
 					g_signal_connect (G_OBJECT(combo), "popup-opened", 
@@ -960,7 +960,8 @@ bool EV_UnixToolbar::synthesize(void)
 					g_signal_connect (G_OBJECT(combo), "popup-closed", 
 									  G_CALLBACK(_wd::s_font_popup_closed), 
 									  wd);
-					g_object_set_data (G_OBJECT (combo), PROP_HANDLER_ID, handler_id);
+					g_object_set_data (G_OBJECT (combo), PROP_HANDLER_ID,
+									   GUINT_TO_POINTER(handler_id));
 					// same size for font and font-size combos
 					// gtk_widget_set_size_request (combo, 0, -1);
 					// gtk_size_group_add_widget (m_wHSizeGroup, combo);
@@ -1204,11 +1205,11 @@ bool EV_UnixToolbar::refreshToolbar(AV_View * pView, AV_ChangeMask mask)
 	for (UT_uint32 k=0; (k < nrLabelItemsInLayout); k++)
 	{
 		EV_Toolbar_LayoutItem * pLayoutItem = m_pToolbarLayout->getLayoutItem(k);
-		UT_ASSERT(pLayoutItem);
+		UT_continue_if_fail(pLayoutItem);
 
 		XAP_Toolbar_Id id = pLayoutItem->getToolbarId();
 		EV_Toolbar_Action * pAction = pToolbarActionSet->getAction(id);
-		UT_ASSERT(pAction);
+		UT_continue_if_fail(pAction);
 
 		AV_ChangeMask maskOfInterest = pAction->getChangeMaskOfInterest();
 		if ((maskOfInterest & mask) == 0)					// if this item doesn't care about
@@ -1436,7 +1437,7 @@ bool EV_UnixToolbar::repopulateStyles(void)
 //
 	UT_ASSERT(wd->m_id == AP_TOOLBAR_ID_FMT_STYLE);
 	XAP_Toolbar_ControlFactory * pFactory = m_pUnixApp->getControlFactory();
-	UT_ASSERT(pFactory);
+	UT_return_val_if_fail(pFactory, false);
 	EV_Toolbar_Control * pControl = pFactory->getControl(this, id);
 	AP_UnixToolbar_StyleCombo * pStyleC = static_cast<AP_UnixToolbar_StyleCombo *>(pControl);
 	pStyleC->repopulate();
