@@ -3,12 +3,12 @@
  * go-file.c :
  *
  * Copyright (C) 2004 Morten Welinder (terra@gnome.org)
- * Copyright (C) 2004 Yukihiro Nakai  <nakai@gnome.gr.jp>
  * Copyright (C) 2003, Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
- * USA
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1558,75 +1558,6 @@ UT_go_file_get_date_changed (char const *uri)
 
 /* ------------------------------------------------------------------------- */
 
-/*
- * UT_go_url_decode: decode the result of UT_go_url_encode.
- */
-gchar*
-UT_go_url_decode (gchar const *text)
-{
-	GString *result;
-
-	g_return_val_if_fail (text != NULL, NULL);
-	g_return_val_if_fail (*text != '\0', NULL);
-
-	result = g_string_new (NULL);
-	while (*text) {
-		unsigned char c = *text++;
-		if (c == '%') {
-			if (g_ascii_isxdigit (text[0]) && g_ascii_isxdigit (text[1])) {
-				g_string_append_c (result,
-						   (g_ascii_xdigit_value (text[0]) << 4) |
-						   g_ascii_xdigit_value (text[1]));
-				text += 2;
-			} else {
-				/* Bogus.  */
-				return g_string_free (result, TRUE);
-			}
-		} else
-			g_string_append_c (result, c);
-	}
-
-	return g_string_free (result, FALSE);
-}
-
-/**
- * UT_go_url_encode: url-encode a string according to RFC 2368.
- */
-gchar*
-UT_go_url_encode (gchar const *text, int type)
-{
-	const char *good;
-	static const char hex[17] = "0123456789ABCDEF";
-	GString* result;
-
-	g_return_val_if_fail (text != NULL, NULL);
-	g_return_val_if_fail (*text != '\0', NULL);
-
-	switch (type) {
-	case 0: /* mailto: */
-		good = ".-_@";
-		break;
-	case 1: /* file: or http: */
-		good = "!$&'()*+,-./:=@_";
-		break;
-	default:
-		return NULL;
-	}
-
-	result = g_string_new (NULL);
-	while (*text) {
-		unsigned char c = *text++;
-		if (g_ascii_isalnum (c) || strchr (good, c))
-			g_string_append_c (result, c);
-		else {
-			g_string_append_c (result, '%');
-			g_string_append_c (result, hex[c >> 4]);
-			g_string_append_c (result, hex[c & 0xf]);
-		}
-	}
-	return g_string_free (result, FALSE);
-}
-
 #ifndef WITH_GNOMEUI
 static char *
 check_program (char const *prog)
