@@ -228,6 +228,7 @@ UT_String& UT_String::operator+=(const char* rhs)
 	return *this;
 }
 
+
 UT_String& UT_String::operator+=(char rhs)
 {
 	char cs = rhs;
@@ -265,148 +266,12 @@ size_t UT_String_findRCh(const UT_String &st, char ch)
   return (size_t)-1;
 }
 
-static UT_uint32
-UT_printf_string_upper_bound (const char* format,
-			      va_list      args)
-{
-  UT_uint32 len = 1;
-
-  while (*format)
-    {
-      bool long_int = false;
-      bool extra_long = false;
-      char c;
-
-      c = *format++;
-
-      if (c == '%')
-	{
-	  bool done = false;
-
-	  while (*format && !done)
-	    {
-	      switch (*format++)
-		{
-		  char *string_arg;
-
-		case '*':
-		  len += va_arg (args, int);
-		  break;
-		case '1':
-		case '2':
-		case '3':
-		case '4':
-		case '5':
-		case '6':
-		case '7':
-		case '8':
-		case '9':
-		  /* add specified format length, since it might exceed the
-		   * size we assume it to have.
-		   */
-		  format -= 1;
-		  len += strtol (format, const_cast<char**>(&format), 10);
-		  break;
-		case 'h':
-		  /* ignore short int flag, since all args have at least the
-		   * same size as an int
-		   */
-		  break;
-		case 'l':
-		  if (long_int)
-		    extra_long = true; /* linux specific */
-		  else
-		    long_int = true;
-		  break;
-		case 'q':
-		case 'L':
-		  long_int = true;
-		  extra_long = true;
-		  break;
-		case 's':
-		  string_arg = va_arg (args, char *);
-		  if (string_arg)
-		    len += strlen (string_arg);
-		  else
-		    {
-		      /* add enough padding to hold "(null)" identifier */
-		      len += 16;
-		    }
-		  done = true;
-		  break;
-		case 'd':
-		case 'i':
-		case 'o':
-		case 'u':
-		case 'x':
-		case 'X':
-		    {
-		      if (long_int)
-			static_cast<void>(va_arg(args, long));
-		      else
-			static_cast<void>(va_arg(args, int));
-		    }
-		  len += extra_long ? 64 : 32;
-		  done = true;
-		  break;
-		case 'D':
-		case 'O':
-		case 'U':
-		  static_cast<void>(va_arg(args, long));
-		  len += 32;
-		  done = true;
-		  break;
-		case 'e':
-		case 'E':
-		case 'f':
-		case 'g':
-		    static_cast<void>(va_arg(args, double));
-		  len += extra_long ? 64 : 32;
-		  done = true;
-		  break;
-		case 'c':
-		  static_cast<void>(va_arg(args, int));
-		  len += 1;
-		  done = true;
-		  break;
-		case 'p':
-		case 'n':
-		  static_cast<void>(va_arg(args, void*));
-		  len += 32;
-		  done = true;
-		  break;
-		case '%':
-		  len += 1;
-		  done = true;
-		  break;
-		default:
-		  /* ignore unknow/invalid flags */
-		  break;
-		}
-	    }
-	}
-      else
-	len += 1;
-    }
-
-  return len;
-}
-
 UT_String& UT_String_vprintf (UT_String & inStr, const char *format,
 			      va_list      args1)
 {
-  char *buffer;
-  va_list args2;
-
-  G_VA_COPY (args2, args1);
-
-  buffer = new char [ UT_printf_string_upper_bound (format, args1) ];
-  vsprintf (buffer, format, args2);
-  va_end (args2);
-
+  char *buffer = g_strdup_vprintf(format, args1);
   inStr = buffer;
-
-  delete [] buffer;
+  g_free(buffer);
 
   return inStr;
 }
@@ -682,6 +547,7 @@ void UT_String_removeProperty(UT_String & sPropertyString, const UT_String & sPr
 
 bool operator==(const UT_String& s1, const UT_String& s2)
 {
+        if (s1.size() != s2.size()) return false;
 	return strcmp(s1.c_str(), s2.c_str()) == 0;
 }
 
@@ -880,6 +746,17 @@ UT_UTF8String &	UT_UTF8String::operator=(const char * rhs)
   return *this;
 }
 
+UT_UTF8String &	UT_UTF8String::operator=(const std::string & rhs)
+{
+  // treat null string assignment as a clear
+  if (rhs.size() == 0)
+    pimpl->clear();
+  else
+    pimpl->assign (rhs.c_str());
+
+  return *this;
+}
+
 UT_UTF8String &	UT_UTF8String::operator=(const UT_UTF8String & rhs)
 {
 	if (this != &rhs) {
@@ -903,6 +780,12 @@ UT_UTF8String &	UT_UTF8String::operator+=(const char * rhs)
 	return *this;
 }
 
+UT_UTF8String& UT_UTF8String::operator+=(const std::string& rhs)
+{
+	pimpl->append(rhs.c_str());
+	return *this;
+}
+
 UT_UTF8String &	UT_UTF8String::operator+=(const UT_UTF8String & rhs)
 {
 	pimpl->append (*rhs.pimpl);
@@ -1293,14 +1176,19 @@ UT_UCS4String UT_UTF8String::ucs4_str ()
 	return ucs4string;
 }
 
+bool operator<(const UT_UTF8String& s1, const UT_UTF8String& s2)
+{
+	return strcmp(s1.utf8_str(), s2.utf8_str()) < 0;
+}
 bool operator==(const UT_UTF8String& s1, const UT_UTF8String& s2)
 {
+        if (s1.size() != s2.size()) return false;
 	return strcmp(s1.utf8_str(), s2.utf8_str()) == 0;
 }
 
 bool operator!=(const UT_UTF8String& s1, const UT_UTF8String& s2)
 {
-	return strcmp(s1.utf8_str(), s2.utf8_str()) != 0;
+	return !(s1 == s2);
 }
 
 bool operator==(const UT_UTF8String& s1, const char * s2)
@@ -1315,11 +1203,13 @@ bool operator!=(const UT_UTF8String& s1, const char * s2)
 
 bool operator==(const UT_UTF8String& s1, const std::string &s2)
 {
+        if (s1.size() != s2.size()) return false;
 	return s1.utf8_str() == s2;
 }
 
 bool operator!=(const UT_UTF8String& s1, const std::string &s2)
 {
+        if (s1.size() != s2.size()) return true;
 	return s1.utf8_str() != s2;
 }
 
@@ -1413,7 +1303,7 @@ UT_UCS4String::UT_UCS4String(const char * utf8_str, size_t bytelength /* 0 == ze
 /* construct from a string in UTF-8 format
  * if (strip_whitespace == true) replace all white space sequences with a single UCS_SPACE
  * if (strip_whitespace != true) replace CR-LF & CR by LF
- * non-breaking spaces (&nbsp; UCS_NBSP 0x0a) are not white space; see UT_UCS4_isspace()
+ * non-breaking spaces (&nbsp; UCS_NBSP 0x0a) are not white space
  */
 UT_UCS4String::UT_UCS4String(const char * utf8_str, size_t bytelength /* 0 == zero-terminate */, bool strip_whitespace)
 	:	pimpl(new UT_StringImpl<UT_UCS4Char>)
@@ -1427,7 +1317,7 @@ UT_UCS4String::UT_UCS4String(const char * utf8_str, size_t bytelength /* 0 == ze
 		if (ucs4a == 0) 
 			break; // end-of-string
 		UT_UCS4Char ucs4b = UT_Unicode::UTF8_to_UCS4 (utf8_str, bytelength);
-		if (UT_UCS4_isspace (ucs4a)) {
+		if ((UCS_NBSP != ucs4a) && UT_UCS4_isspace (ucs4a)) {
 			if (strip_whitespace) {
 				if (!UT_UCS4_isspace (ucs4b)) {
 					ucs4a = UCS_SPACE;
@@ -1587,6 +1477,7 @@ void UT_UCS4String::swap(UT_UCS4String& rhs)
 
 bool operator==(const UT_UCS4String& s1, const UT_UCS4String& s2)
 {
+        if (s1.size() != s2.size()) return false;
 	return UT_UCS4_strcmp(s1.ucs4_str(), s2.ucs4_str()) == 0;
 }
 
