@@ -24,6 +24,9 @@
  * Author: INdT - Renato Araujo <renato.filho@indt.org.br>
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <gtk/gtk.h>
 #include <stdio.h>
@@ -47,19 +50,20 @@
 #include "ut_debugmsg.h"
 #include "ut_string_class.h"
 #include "ut_path.h"
-
 #include "ut_png.h"
 #include "ut_svg.h"
 #include "ut_misc.h"
 #include "fg_Graphic.h"
 #include "fg_GraphicRaster.h"
+#include "ie_impGraphic.h"
 
 #include "gr_UnixImage.h"
 #include "gr_Painter.h"
 #include "gr_UnixPangoGraphics.h"
+#include "ut_bytebuf.h"
 
 #if defined(EMBEDDED_TARGET) && EMBEDDED_TARGET == EMBEDDED_TARGET_HILDON
-#include <hildon-widgets/hildon-file-chooser-dialog.h>
+#include <hildon/hildon-file-chooser-dialog.h>
 #endif
 
 
@@ -99,7 +103,7 @@ XAP_UnixDialog_FileOpenSaveAs::~XAP_UnixDialog_FileOpenSaveAs(void)
 
 static void s_dialog_response(GtkWidget * /* widget */,
 						gint answer,
-						XAP_Dialog_FileOpenSaveAs::tAnswer * ptr)
+						XAP_Dialog_FileOpenSaveAs::tAnswer * ptr, bool bQuit = true)
 {
 	switch (answer)
 	{
@@ -110,7 +114,8 @@ static void s_dialog_response(GtkWidget * /* widget */,
 				*ptr = XAP_Dialog_FileOpenSaveAs::a_CANCEL;
 			else
 				*ptr = XAP_Dialog_FileOpenSaveAs::a_OK;
-			gtk_main_quit();
+			if (bQuit)
+				gtk_main_quit();
 			break;
 		default:
 			// do nothing
@@ -118,6 +123,12 @@ static void s_dialog_response(GtkWidget * /* widget */,
 	}
 }
 
+static void dialog_response(GtkWidget *widget,
+                                                       gint answer,
+                                                       XAP_Dialog_FileOpenSaveAs::tAnswer * ptr) {
+       s_dialog_response(widget, answer, ptr);
+}
+
 static void s_delete_clicked(GtkWidget 	*widget, 
 							 GdkEvent 	*event, 
 							 gpointer 	 data)
@@ -127,6 +138,7 @@ static void s_delete_clicked(GtkWidget 	*widget,
 	gtk_main_quit();
 }
 
+
 static gint s_preview_exposed(GtkWidget * /* widget */,
 			      GdkEventExpose * /* pExposeEvent */,
 			      gpointer ptr)
@@ -148,8 +160,8 @@ fsel_key_event (GtkWidget *widget, GdkEventKey *event, XAP_Dialog_FileOpenSaveAs
 {
 #ifdef GDK_Escape
 	if (event->keyval == GDK_Escape) {
-		g_signal_emit_stop_by_name (G_OBJECT (widget), "key_press_event");
-		s_cancel_clicked ( widget, answer ) ;
+		g_signal_stop_emission_by_name (G_OBJECT (widget), "key_press_event");
+		s_dialog_response(widget, GTK_RESPONSE_CANCEL, answer);
 		return TRUE;
 	}
 #endif
@@ -159,7 +171,12 @@ fsel_key_event (GtkWidget *widget, GdkEventKey *event, XAP_Dialog_FileOpenSaveAs
 
 static void s_file_activated(GtkWidget * w, XAP_Dialog_FileOpenSaveAs::tAnswer * answer)
 {
-	s_dialog_response(w, GTK_RESPONSE_ACCEPT, answer);
+	// whenever the "file-activated" signal is called, it will also be followed
+	// (or preceded?) by a "response" signal. That "response" signal will manage
+	// the closing of the dialog for us. Now we don't want to close the dialog 
+	// twice, hence the last 'false' parameter.
+	// Hardly elegant, but none of this code is :/ It fixes bug #11647 too - MARCM.
+	s_dialog_response(w, GTK_RESPONSE_ACCEPT, answer, false);
 }
 
 static void file_selection_changed  (GtkTreeSelection  *selection,
@@ -227,10 +244,9 @@ bool XAP_UnixDialog_FileOpenSaveAs::_run_gtk_main(XAP_Frame * pFrame,
 				continue;
 	
 			// We append the suffix of the default type, so the user doesn't
-				// have to.  This is adapted from the Windows front-end code
+			// have to.  This is adapted from the Windows front-end code
 			// (xap_Win32Dlg_FileOpenSaveAs.cpp), since it should act the same.
 			// If, however, the user doesn't want suffixes, they don't have to have them.  
-	
 			{
 				//UT_uint32 end = g_strv_length(m_szSuffixes);
 	
@@ -258,28 +274,33 @@ bool XAP_UnixDialog_FileOpenSaveAs::_run_gtk_main(XAP_Frame * pFrame,
 						}
 					}
 				}
-				bool wantSuffix = true;
 				
+				bool wantSuffix = true;
 				XAP_Prefs *pPrefs= XAP_App::getApp()->getPrefs();
-	
 				pPrefs->getPrefsValueBool(static_cast<const gchar *>(XAP_PREF_KEY_UseSuffix), &wantSuffix);
-	
 				UT_DEBUGMSG(("UseSuffix: %d\n", wantSuffix));
 
-#if 0	
-				struct stat buf;
-				// do not want suffix for directory names
-				err = stat(szDialogFilename, &buf);
-				if ((err == 0) && (S_ISDIR(buf.st_mode)))
-					wantSuffix = false;
-#endif
-	
-				// if the file doesn't have a suffix already, and the file type
-				// is normal (special types are negative, like auto detect),
-				// and the user wants extensions, slap a suffix on it.   
-				if ((!UT_pathSuffix(szDialogFilename)) && 
-					(nFileType > 0) && wantSuffix)                                
-					{                                                       
+				if (nFileType > 0) // 0 means autodetect
+				{
+					if (UT_pathSuffix(szDialogFilename))
+					{
+						// warn if we have a suffix that doesn't match the selected file type
+						IE_ExpSniffer* pSniffer = IE_Exp::snifferForFileType(m_nTypeList[nIndex]);
+						if (pSniffer && !pSniffer->recognizeSuffix(UT_pathSuffix(szDialogFilename)))
+						{
+							UT_UTF8String msg;
+							const XAP_StringSet * pSS = m_pApp->getStringSet();
+							pSS->getValueUTF8(XAP_STRING_ID_DLG_FOSA_ExtensionDoesNotMatch, msg);
+							if (pFrame->showMessageBox(msg.utf8_str(), XAP_Dialog_MessageBox::b_YN, XAP_Dialog_MessageBox::a_NO) != XAP_Dialog_MessageBox::a_YES)
+								goto ContinueLoop;
+						}
+						szFinalPathname = g_strdup(szDialogFilename);
+					}
+					else if (wantSuffix)                                
+					{
+						// if the file doesn't have a suffix already, and the file type
+						// is normal (special types are negative, like auto detect),
+						// and the user wants extensions, slap a suffix on it.						
 						// add suffix based on selected file type       
 						UT_UTF8String suffix (IE_Exp::preferredSuffixForFileType(m_nTypeList[nIndex]));
 						UT_uint32 length = strlen(szDialogFilename) + suffix.size() + 1;
@@ -287,20 +308,23 @@ bool XAP_UnixDialog_FileOpenSaveAs::_run_gtk_main(XAP_Frame * pFrame,
 						szFinalPathname = static_cast<char *>(UT_calloc(length,sizeof(char)));
 						
 						if (szFinalPathname)                            						
-							{                                               
-								char * p = szFinalPathname;             
-								strcpy(p,szDialogFilename);             
-								strcat(p,suffix.utf8_str());                     
-							}                                               
-						
-					}                                                       
-				else                                                    
-					{                                                       
-						// the file type is special (auto detect)       
-						// set to plain name, and let the auto detector in the
-						// exporter figure it out                       
+						{                                               
+							char * p = szFinalPathname;             
+							strcpy(p,szDialogFilename);             
+							strcat(p,suffix.utf8_str());                     
+						}                                               
+					}
+					else
 						szFinalPathname = g_strdup(szDialogFilename);
-					}                                                       
+				}
+				else                                                    
+				{                                                       
+					// the file type is special (auto detect)       
+					// set to plain name, and let the auto detector in the
+					// exporter figure it out                       
+					szFinalPathname = g_strdup(szDialogFilename);
+				}                                                       
+
 				// g_free szDialogFilename since it's been put into szFinalPathname (with
 				// or without changes) and it's invalid (missing an extension which
 				// might have been appended)                            
@@ -310,14 +334,9 @@ bool XAP_UnixDialog_FileOpenSaveAs::_run_gtk_main(XAP_Frame * pFrame,
 
 			szFinalPathnameCopy = g_strdup(szFinalPathname);
 
-			bool exists = UT_go_file_exists(szFinalPathnameCopy);
-				
-			// Does the filename already exist?
-	
-			if (exists)
+			if (UT_go_file_exists(szFinalPathnameCopy))
 			{
 				// we have an existing file, ask to overwrite
-	
 				if (_askOverwrite_YesNo(pFrame, szFinalPathname))
 				{
 					m_szFinalPathnameCandidate = g_strdup(szFinalPathname);
@@ -345,40 +364,6 @@ bool XAP_UnixDialog_FileOpenSaveAs::_run_gtk_main(XAP_Frame * pFrame,
 
 			m_szFinalPathnameCandidate = g_strdup(szFinalPathname);
 			goto ReturnTrue;
-	
-#if 0			
-			// Trim the pathname at beginning of the filename
-			// keeping the trailing slash.
-				
-			pLastSlash[1] = 0;
-	
-			// Stat the directory left over
-	
-			err = stat(szFinalPathnameCopy, &buf);
-			UT_ASSERT(err == 0 || err == -1);
-	
-			// If this directory doesn't exist, we have been feed garbage
-			// at some point.  Throw an error and continue with the selection.
-	
-			if (err == -1)
-			{
-				_notifyError_OKOnly(pFrame,XAP_STRING_ID_DLG_NoSaveFile_DirNotExist);
-				goto ContinueLoop;
-			}
-	
-			// Since the stat passed the last test, we will make sure the
-			// directory is suitable for writing, since we know it exists.
-	
-			UT_ASSERT(S_ISDIR(buf.st_mode));
-	
-			if (!access(szFinalPathnameCopy, W_OK))
-			{
-				// we've got what we need, save it to the candidate
-				m_szFinalPathnameCandidate = g_strdup(szFinalPathname);
-				goto ReturnTrue;
-			}
-	
-#endif
 
 			// complain about write permission on the directory.
 			// lop off ugly trailing slash only if we don't have
@@ -441,9 +426,11 @@ void XAP_UnixDialog_FileOpenSaveAs::fileTypeChanged(GtkWidget * w)
 	{
 		return;
 	}
-	gchar * uri = gtk_file_chooser_get_uri(m_FC);
-	UT_String sFileName(uri);
-	FREEP(uri);
+
+	gchar * filename = gtk_file_chooser_get_filename(m_FC);
+	UT_String sFileName = filename;
+	FREEP(filename);
+
 	UT_String sSuffix = m_szSuffixes[nFileType-1];
 	sSuffix = sSuffix.substr(1,sSuffix.length()-1);
 	UT_sint32 i = 0;
@@ -598,9 +585,7 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 	GtkWidget * parent = pUnixFrameImpl->getTopLevelWindow();
 
 #if defined(EMBEDDED_TARGET) && EMBEDDED_TARGET == EMBEDDED_TARGET_HILDON
-	GtkWidget * wHildonView = gtk_widget_get_parent(parent);
-
-	m_FC = GTK_FILE_CHOOSER( hildon_file_chooser_dialog_new(GTK_WINDOW(wHildonView),
+	m_FC = GTK_FILE_CHOOSER( hildon_file_chooser_dialog_new(GTK_WINDOW(parent),
 							(!m_bSave ? GTK_FILE_CHOOSER_ACTION_OPEN : GTK_FILE_CHOOSER_ACTION_SAVE))
 							);
 	
@@ -617,7 +602,7 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 									GTK_WINDOW(parent),
 									(!m_bSave ? GTK_FILE_CHOOSER_ACTION_OPEN : GTK_FILE_CHOOSER_ACTION_SAVE),
 									GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-									GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+									(m_bSave ? GTK_STOCK_SAVE : GTK_STOCK_OPEN), GTK_RESPONSE_ACCEPT,
 									(gchar*)NULL)
 							);
 	xxx_UT_DEBUGMSG(("Have the filechooser now \n"));
@@ -641,7 +626,6 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 	gtk_widget_show(pulldown_hbox);
 	gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER(m_FC), pulldown_hbox);
 
-#if 0
 	if (m_id == XAP_DIALOG_ID_INSERT_PICTURE)
 	{
 		GtkWidget * preview = createDrawingArea ();
@@ -665,7 +649,6 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 		g_signal_connect (preview, "expose_event",
 								G_CALLBACK (s_preview_exposed), static_cast<gpointer>(this));
 	}
-#endif
 
 	// pulldown label
 	GtkWidget * filetypes_label = gtk_label_new(szFileTypeLabel.utf8_str());
@@ -673,13 +656,9 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 	gtk_misc_set_alignment(GTK_MISC(filetypes_label), 1.0, 0.5);
 	gtk_widget_show(filetypes_label);
 
-	int VOFFSET = 0;
-	if (m_id == XAP_DIALOG_ID_INSERT_PICTURE)
-	  VOFFSET = 40;
-
 	GtkWidget * vboxTmp = gtk_vbox_new (FALSE, 0);
 	gtk_widget_show (vboxTmp);
-	gtk_box_pack_start (GTK_BOX(vboxTmp), filetypes_label, FALSE, FALSE, VOFFSET);
+	gtk_box_pack_start (GTK_BOX(vboxTmp), filetypes_label, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(pulldown_hbox), vboxTmp, FALSE, TRUE, 0);		
 
 	// pulldown menu
@@ -689,7 +668,7 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 	// hack so that i can make this widget small vertically
 	vboxTmp = gtk_vbox_new (FALSE, 0);
 	gtk_widget_show (vboxTmp);
-	gtk_box_pack_start (GTK_BOX(vboxTmp), filetypes_pulldown, FALSE, FALSE, VOFFSET);
+	gtk_box_pack_start (GTK_BOX(vboxTmp), filetypes_pulldown, FALSE, FALSE, 0);
 	gtk_box_pack_end(GTK_BOX(pulldown_hbox), vboxTmp, FALSE, TRUE, 0);
 
 	//
@@ -768,7 +747,7 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 
 	g_signal_connect (G_OBJECT (m_FC),
 				"response",
-				G_CALLBACK(s_dialog_response), &m_answer);
+				G_CALLBACK(dialog_response), &m_answer);
 	
 	g_signal_connect (G_OBJECT (m_FC),
 				"file-activated",
@@ -813,6 +792,8 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 
 		if (m_bSuggestName)
 		{
+			xxx_UT_DEBUGMSG(("Iniitial filename is %s \n",m_szInitialPathname));
+#if 0
 			if (!g_path_is_absolute (m_szInitialPathname)) { // DAL: todo: is this correct?
 				gchar *dir = g_get_current_dir ();
 				gchar *file = m_szInitialPathname;
@@ -822,6 +803,7 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 				g_free (dir);
 				g_free (file);
 			}
+#endif
 			if(m_id == XAP_DIALOG_ID_FILE_SAVEAS)
 			{
 				const char * szInitialSuffix = UT_pathSuffix(m_szInitialPathname);
@@ -849,7 +831,7 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 					}
 				}
 			}
-			gtk_file_chooser_set_filename(m_FC, m_szInitialPathname);
+			gtk_file_chooser_set_uri(m_FC, m_szInitialPathname);
 		}
 		else
 		{
@@ -929,7 +911,6 @@ gint XAP_UnixDialog_FileOpenSaveAs::previewPicture (void)
 	int answer = 0;
 
 	FG_Graphic * pGraphic = 0;
-	UT_Error errorCode = UT_OK;
 	GR_Image *pImage = NULL;
 
 	double		scale_factor = 0.0;
@@ -941,60 +922,88 @@ gint XAP_UnixDialog_FileOpenSaveAs::previewPicture (void)
 	painter.clearArea(0, 0, pGr->tlu(m_preview->allocation.width), pGr->tlu(m_preview->allocation.height));
 
 	if (!file_name)
-	  {
+	{
 		painter.drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(static_cast<int>(m_preview->allocation.height / 2)) - pGr->getFontHeight(fnt)/2);
 	    goto Cleanup;
-	  }
+	}
 
 	// are we dealing with a file or directory here?
 	struct stat st;
-	if (!stat (file_name, &st)) {
-		if (!S_ISREG(st.st_mode)) {
+	if (!stat (file_name, &st)) 
+	{
+		if (!S_ISREG(st.st_mode)) 
+		{
 			painter.drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(static_cast<int>(m_preview->allocation.height / 2)) - pGr->getFontHeight(fnt)/2);
 			goto Cleanup;
 		}
 	}
-	else {
-		painter.drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(static_cast<int>(m_preview->allocation.height / 2)) - pGr->getFontHeight(fnt)/2);
+
+	GsfInput * input = NULL;
+	UT_DEBUGMSG(("file_name %s \n",file_name));
+	input = UT_go_file_open (file_name, NULL);
+	if (!input)
 		goto Cleanup;
-	}
+	char Buf[4097] = "";  // 4096+nul ought to be enough
+	UT_uint32 iNumbytes = UT_MIN(4096, gsf_input_size(input));
+	gsf_input_read(input, iNumbytes, (guint8 *)(Buf));
+	Buf[iNumbytes] = '\0';
 
-	// Build an Import Graphic based on file type
-	errorCode = IE_ImpGraphic::loadGraphic(file_name, IEGFT_Unknown, &pGraphic);
-	if ((errorCode != UT_OK) || !pGraphic)
-	  {
+	IEGraphicFileType ief = IE_ImpGraphic::fileTypeForContents(Buf,4096);
+	if((ief == IEGFT_Unknown) || (ief == IEGFT_Bogus))
+	{
+		    painter.drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(static_cast<int>(m_preview->allocation.height / 2)) - pGr->getFontHeight(fnt)/2);
+			g_object_unref (G_OBJECT (input));
+			goto Cleanup;
+	}
+	g_object_unref (G_OBJECT (input));
+	input = UT_go_file_open (file_name, NULL);
+	size_t num_bytes = gsf_input_size(input);
+	UT_Byte * bytes = (UT_Byte *) gsf_input_read(input, num_bytes,NULL );
+	if(bytes == NULL)
+	{
+		    painter.drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(static_cast<int>(m_preview->allocation.height / 2)) - pGr->getFontHeight(fnt)/2);
+			g_object_unref (G_OBJECT (input));
+			goto Cleanup;
+	}
+	UT_ByteBuf * pBB = new UT_ByteBuf();
+	pBB->append(bytes,num_bytes);
+	g_object_unref (G_OBJECT (input));
+	//
+	// OK load the data into a GdkPixbuf
+	//
+	bool bLoadFailed = false;
+	//
+	GdkPixbuf * pixbuf = pixbufForByteBuf ( pBB);
+	delete pBB;
+	if(pixbuf == NULL)
+	{
+		//
+		// Try a fallback loader here.
+		//
 		painter.drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(static_cast<int>(m_preview->allocation.height / 2)) - pGr->getFontHeight(fnt)/2);
+		bLoadFailed = true;
 	    goto Cleanup;
-	  }
-
-	if ( FGT_Raster == pGraphic->getType () )
-	{
-		pImage = new GR_UnixImage(NULL);
-
-		UT_ByteBuf * png = static_cast<FG_GraphicRaster*>(pGraphic)->getRaster_PNG();
-		UT_PNG_getDimensions (png, iImageWidth, iImageHeight);
-
-		if (m_preview->allocation.width >= iImageWidth && m_preview->allocation.height >= iImageHeight)
-		  scale_factor = 1.0;
-		else
-		  scale_factor = MIN( static_cast<double>(m_preview->allocation.width)/iImageWidth,
-				      static_cast<double>(m_preview->allocation.height)/iImageHeight);
-		
-		scaled_width  = static_cast<int>(scale_factor * iImageWidth);
-		scaled_height = static_cast<int>(scale_factor * iImageHeight);
-
-		pImage->convertFromBuffer(png, scaled_width, scaled_height);
-		
-		painter.drawImage(pImage,
-			       pGr->tlu(static_cast<int>((m_preview->allocation.width  - scaled_width ) / 2)),
-			       pGr->tlu(static_cast<int>((m_preview->allocation.height - scaled_height) / 2)));
-		
-		answer = 1;
 	}
+
+	pImage = new GR_UnixImage(NULL,pixbuf);
+
+	iImageWidth = gdk_pixbuf_get_width (pixbuf);
+	iImageHeight = gdk_pixbuf_get_height (pixbuf);
+	if (m_preview->allocation.width >= iImageWidth && m_preview->allocation.height >= iImageHeight)
+		scale_factor = 1.0;
 	else
-	{
-	  UT_ASSERT_NOT_REACHED ();
-	}
+		scale_factor = MIN( static_cast<double>(m_preview->allocation.width)/iImageWidth,
+							static_cast<double>(m_preview->allocation.height)/iImageHeight);
+		
+	scaled_width  = static_cast<int>(scale_factor * iImageWidth);
+	scaled_height = static_cast<int>(scale_factor * iImageHeight);
+
+	static_cast<GR_UnixImage *>(pImage)->scale(scaled_width,scaled_height);	
+	painter.drawImage(pImage,
+					  pGr->tlu(static_cast<int>((m_preview->allocation.width  - scaled_width ) / 2)),
+					  pGr->tlu(static_cast<int>((m_preview->allocation.height - scaled_height) / 2)));
+		
+	answer = 1;
 	}
 	
  Cleanup:
@@ -1005,3 +1014,151 @@ gint XAP_UnixDialog_FileOpenSaveAs::previewPicture (void)
 
 	return answer;
 }
+
+GdkPixbuf *  XAP_UnixDialog_FileOpenSaveAs::_loadXPM(UT_ByteBuf * pBB)
+{
+	GdkPixbuf * pixbuf = NULL;
+	const char * pBC = reinterpret_cast<const char *>(pBB->getPointer(0));
+
+	UT_GenericVector<char*> vecStr;
+	UT_sint32 k =0;
+	UT_sint32 iBase =0;
+
+	//
+	// Find dimension line to start with.
+	//
+	UT_sint32 length = static_cast<UT_sint32>(pBB->getLength());
+	for(k =0; (*(pBC+k) != '"') &&( k < length); k++)
+		;
+
+	if(k >= length)
+	{
+		return NULL;
+	}
+
+	k++;
+	iBase = k;
+	for(k =k; (*(pBC+k) != '"') && (k < length); k++)
+		;
+	if(k >= length)
+	{
+		return NULL;
+	}
+
+	char * sz = NULL;
+	UT_sint32 kLen = k-iBase+1;
+	sz = static_cast<char *>(UT_calloc(kLen,sizeof(char)));
+	UT_sint32 i =0;
+
+	for(i=0; i< (kLen -1); i++)
+	{
+		*(sz+i) = *(pBC+iBase+i);
+	}
+	*(sz+i) = 0;
+	vecStr.addItem(sz);
+
+	//
+	// Now loop through all the lines until we get to "}" outside the
+	// '"'
+	while((*(pBC+k) != '}')  && (k < length) )
+	{
+		k++;
+
+		//
+		// Load a single string of data into our vector.
+		// 
+		if(*(pBC+k) =='"')
+		{
+			//
+			// Start of a line
+			//
+			k++;
+			iBase = k;
+			for(k =k; (*(pBC+k) != '"') && (k < length); k++) {}
+			if(k >= length)
+			{
+				return NULL;
+			}
+			sz = NULL;
+			kLen = k-iBase+1;
+			sz = static_cast<char *>(UT_calloc(kLen,sizeof(char)));
+			for(i=0; i<(kLen -1); i++)
+			{
+				*(sz+i) = *(pBC+iBase+i);
+			}
+			*(sz +i) = 0;
+			vecStr.addItem(sz);
+		}
+	}
+
+	if(k >= length)
+	{
+		for(i=0; i< static_cast<UT_sint32>(vecStr.getItemCount()); i++)
+		{
+			char * psz = vecStr.getNthItem(i);
+			FREEP(psz);
+		}
+		return NULL;
+	}
+
+	const char ** pszStr = static_cast<const char **>(UT_calloc(vecStr.getItemCount(),sizeof(char *)));
+	for(i=0; i< static_cast<UT_sint32>(vecStr.getItemCount()); i++)
+		pszStr[i] = vecStr.getNthItem(i);
+	pixbuf = gdk_pixbuf_new_from_xpm_data(pszStr);
+	DELETEP(pszStr);
+	return pixbuf;
+}
+
+GdkPixbuf *  XAP_UnixDialog_FileOpenSaveAs::pixbufForByteBuf (UT_ByteBuf * pBB)
+{
+	if ( !pBB || !pBB->getLength() )
+		return NULL;
+
+	GdkPixbuf * pixbuf = NULL;
+
+	bool bIsXPM = false;
+	const char * szBuf = reinterpret_cast<const char *>(pBB->getPointer(0));
+	if((pBB->getLength() > 9) && (strncmp (szBuf, "/* XPM */", 9) == 0))
+	{
+		bIsXPM = true;
+	}
+
+	if(bIsXPM)
+	{
+		pixbuf = _loadXPM(pBB);
+	}
+	else
+	{
+		GError * err = 0;
+		GdkPixbufLoader * ldr = 0;
+
+		ldr = gdk_pixbuf_loader_new ();
+		if (!ldr)
+			{
+				UT_DEBUGMSG (("GdkPixbuf: couldn't create loader! WTF?\n"));
+				UT_ASSERT (ldr);
+				return NULL ;
+			}
+
+		if ( FALSE== gdk_pixbuf_loader_write (ldr, static_cast<const guchar *>(pBB->getPointer (0)),
+											  static_cast<gsize>(pBB->getLength ()), &err) )
+			{
+				UT_DEBUGMSG(("DOM: couldn't write to loader: %s\n", err->message));
+				g_error_free(err);
+				gdk_pixbuf_loader_close (ldr, NULL);
+				g_object_unref (G_OBJECT(ldr));
+				return NULL ;
+			}
+		
+		gdk_pixbuf_loader_close (ldr, NULL);
+		pixbuf = gdk_pixbuf_loader_get_pixbuf (ldr);
+
+		// ref before closing the loader
+		if ( pixbuf )
+			g_object_ref (G_OBJECT(pixbuf));
+
+		g_object_unref (G_OBJECT(ldr));
+	}
+
+	return pixbuf;
+}
