@@ -123,7 +123,7 @@ abi_table_resize(AbiTable* table)
 	g_return_if_fail(table);
 
 	if (table->selected_rows == 0 && table->selected_cols == 0)
-		text = g_strdup_printf(table->szCancel);
+		text = g_strdup(table->szCancel);
 	else
 	{
 		UT_UTF8String prText =  "%d x %d ";
@@ -176,7 +176,7 @@ abi_table_set_max_size (AbiTable* abi_table, guint rows, guint cols)
 
 
 extern "C" void
-abi_table_set_labels(AbiTable* abi_table, gchar * szTable, gchar * szCancel)
+abi_table_set_labels(AbiTable* abi_table, const gchar * szTable, const gchar * szCancel)
 {
 	if(abi_table->szTable)
 		g_free(abi_table->szTable);
@@ -579,8 +579,8 @@ register_stock_icon(void)
 		GtkIconFactory *factory;
 
 		static GtkStockItem items[] = {
-			{ "abi-table-widget",
-			  "_Table",
+			{ (gchar*)"abi-table-widget",
+			  (gchar*)"_Table",
 			  static_cast<GdkModifierType>(0), 0, NULL }
 		};
       
