@@ -17,6 +17,10 @@
  * 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 
@@ -516,7 +520,9 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 					const gchar* pszID = NULL;
 					pAP->getAttribute("id", pszID);
 
-					fl_DocSectionLayout* pDocSL = m_pLayout->findSectionForHdrFtr((char*)pszID);
+					fl_DocSectionLayout* pDocSL = NULL;
+					if(pszID)
+						pDocSL = m_pLayout->findSectionForHdrFtr((char*)pszID);
 					if (pDocSL == NULL)
 					{
 						UT_DEBUGMSG(("Could not find HeaderFooter %s\n",(char*)pszID));
@@ -584,7 +590,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 				return false;
 			}
 			// BUGBUG: this is *not* thread-safe, but should work for now
-#ifndef WITHOUT_SPELL
+#ifdef ENABLE_SPELL
 			if (m_bScreen)
 			{
 				UT_uint32 reason =  0;
@@ -611,7 +617,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 			}
 
 			// BUGBUG: this is *not* thread-safe, but should work for now
-#ifndef WITHOUT_SPELL
+#ifdef ENABLE_SPELL
 			if (m_bScreen)
 			{
 				UT_uint32 reason =  0;
@@ -1513,6 +1519,7 @@ bool fl_DocListener::change(PL_StruxFmtHandle sfh,
 		fl_Layout * pL = (fl_Layout *)sfh;
 		UT_ASSERT(pL->getType() == PTX_Block);
 		fl_ContainerLayout * pCL = static_cast<fl_ContainerLayout *>(pL);
+		xxx_UT_DEBUGMSG(("ContainerLayout %x ContainerType %s \n",pCL,pCL->getContainerString()));
 		pCL->listUpdate();
 		goto finish_up;
 
