@@ -1971,9 +1971,12 @@ bool fl_CellLayout::isCellSelected(void)
 	PT_DocPosition posStartCell = 0;
 	PT_DocPosition posEndCell =0;
 	PL_StruxDocHandle sdhEnd,sdhStart;
+
 	sdhStart = getStruxDocHandle();
 	posStartCell = m_pDoc->getStruxPosition(sdhStart) +1;
-	m_pDoc->getNextStruxOfType(sdhStart, PTX_EndCell, &sdhEnd);
+	bool bRes = m_pDoc->getNextStruxOfType(sdhStart, PTX_EndCell, &sdhEnd);
+	UT_return_val_if_fail(bRes, false);
+
 	posEndCell = m_pDoc->getStruxPosition(sdhEnd) -1;
 	if(pView->isPosSelected(posStartCell) && pView->isPosSelected(posEndCell))
 	{
@@ -2931,6 +2934,7 @@ static void s_border_properties_cell (const char * border_color,
 	}
 	else //
 	{
+		// default to 0.72pt
 		line.m_t_thickness = PP_PropertyMap::thickness_length;
 		double thickness = UT_LAYOUT_RESOLUTION;
 		line.m_thickness = static_cast<UT_sint32>(thickness / UT_PAPER_UNITS_PER_INCH);
