@@ -54,7 +54,8 @@ fp_ContainerObject::fp_ContainerObject(FP_ContainerType iType, fl_SectionLayout*
 	:       m_iConType(iType),
 			m_pSectionLayout(pSectionLayout),
 			m_iDirection(UT_BIDI_UNSET),
-			m_iBreakTick(0)
+		m_iBreakTick(0),
+		m_iRef(0)
 {
 	UT_ASSERT(pSectionLayout);
 }
@@ -187,6 +188,20 @@ void fp_Container::setMyBrokenContainer(fp_Container * pMyBroken)
 	}
 }
 
+void fp_Container::setNext(fp_ContainerObject * pNext)
+{
+  m_pNext = pNext;
+  if(pNext)
+    pNext->ref();
+}
+
+void fp_Container::setPrev(fp_ContainerObject * pPrev)
+{
+  m_pPrev = pPrev;
+  if(pPrev)
+    pPrev->ref();
+}
+
 /*!
  * Recursive clears all broken containers contained by this container
  */
@@ -325,6 +340,7 @@ void fp_Container::insertConAt(fp_ContainerObject * pCon, UT_sint32 i)
 	}
 #endif
 	m_vecContainers.insertItemAt(pCon,i);
+	pCon->ref();
 }
 
 void fp_Container::addCon(fp_ContainerObject * pCon)
@@ -348,6 +364,7 @@ void fp_Container::addCon(fp_ContainerObject * pCon)
 	}
 #endif
 	m_vecContainers.addItem(pCon);
+	pCon->ref();
 }
 
 fp_ContainerObject *  fp_Container:: getNthCon(UT_uint32 i) const
@@ -423,6 +440,8 @@ bool fp_Container::getPageRelativeOffsets(UT_Rect &r) const
 
 void fp_Container::justRemoveNthCon(UT_sint32 i)
 {
+        fp_ContainerObject * pCon = getNthCon(i);
+	pCon->unref();
 	m_vecContainers.deleteNthItem(i);
 }
 
@@ -434,6 +453,7 @@ void  fp_Container::deleteNthCon(UT_sint32 i)
 		UT_ASSERT(0);
 		pCon->setContainer(NULL);
 	}
+	pCon->unref();
 	m_vecContainers.deleteNthItem(i);
 	xxx_UT_DEBUGMSG(("AFter deleting item %d in %x there are %d cons left \n",i,this,countCons()));
 }
@@ -659,7 +679,7 @@ void  fg_FillType::setDocLayout(FL_DocLayout * pDocLayout)
 }
 
 /*!
- * Set that the fill should be transperent if we're printing.
+ * Set that the fill should be transparent if we're printing.
  */
 void fg_FillType::markTransparentForPrint(void)
 {
@@ -689,6 +709,8 @@ void fg_FillType::_regenerateImage(GR_Graphics * pG)
 	DELETEP(m_pImage);
 	m_pImage = m_pGraphic->regenerateImage(pG);
 	setWidthHeight(pG,m_iWidth,m_iHeight);
+	UT_Rect rec(0,0,m_iWidth,m_iHeight);
+	m_pImage->scaleImageTo(pG,rec);
 	m_iGraphicTick = m_pDocLayout->getGraphicTick();
 }
 
