@@ -1,3 +1,4 @@
+
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
  * Copyright (C) 2002 Patrick Lam <plam@mit.edu>
@@ -28,6 +29,7 @@
 #include "fp_Page.h"
 #include "fp_Line.h"
 #include "fl_DocLayout.h"
+#include "pd_Document.h"
 #include "fl_SectionLayout.h"
 #include "gr_DrawArgs.h"
 #include "ut_vector.h"
@@ -57,7 +59,8 @@ fp_FrameContainer::fp_FrameContainer(fl_SectionLayout* pSectionLayout)
 	  m_bIsAbove(true),
 	  m_bIsTopBot(false),
 	  m_bIsLeftWrapped(false),
-	  m_bIsRightWrapped(false)
+	  m_bIsRightWrapped(false),
+	  m_iPreferedPageNo(-1)
 {
 }
 
@@ -81,6 +84,19 @@ void fp_FrameContainer::setPage(fp_Page * pPage)
 		clearScreen();
 		m_pPage->removeFrameContainer(this);
 		getSectionLayout()->markAllRunsDirty();
+		
+		UT_GenericVector<fl_ContainerLayout *> AllLayouts;
+		AllLayouts.clear();
+		m_pPage->getAllLayouts(AllLayouts);
+		UT_uint32 i = 0;
+		for(i=0; i<AllLayouts.getItemCount(); i++)
+		{
+		      fl_ContainerLayout * pCL = AllLayouts.getNthItem(i);
+		      pCL->collapse();
+		      pCL->format();
+	        }
+		m_pPage->getOwningSection()->setNeedsSectionBreak(true,m_pPage);
+		
 	}
 	m_pPage = pPage;
 	if(pPage)
@@ -165,6 +181,25 @@ bool fp_FrameContainer::overlapsRect(UT_Rect & rec)
      delete pMyFrameRec;
      return false;
 }
+
+void fp_FrameContainer::setPreferedPageNo(UT_sint32 i)
+{
+     if(m_iPreferedPageNo == i)
+       return;
+     m_iPreferedPageNo =  i;
+     fl_FrameLayout * pFL = static_cast<fl_FrameLayout *>(getSectionLayout());
+     FL_DocLayout * pDL = pFL->getDocLayout();
+     if(pDL->isLayoutFilling())
+       return;
+     PD_Document * pDoc = pDL->getDocument();
+     UT_UTF8String sVal;
+     UT_UTF8String_sprintf(sVal,"%d",i);
+     const char * attr = PT_PROPS_ATTRIBUTE_NAME;
+     UT_UTF8String sAttVal = "pref-page:";
+     sAttVal += sVal.utf8_str();
+     
+     pDoc->changeStruxAttsNoUpdate(pFL->getStruxDocHandle(),attr,sAttVal.utf8_str());
+}
 /*!
  * This method returns the padding to be applied between a line approaching
  * wrapped frame or image from the left. 
@@ -328,7 +363,7 @@ void fp_FrameContainer::setContainer(fp_Container * pContainer)
 fl_DocSectionLayout * fp_FrameContainer::getDocSectionLayout(void)
 {
 	fl_FrameLayout * pFL = static_cast<fl_FrameLayout *>(getSectionLayout());
-	fl_DocSectionLayout * pDSL = static_cast<fl_DocSectionLayout *>(pFL->myContainingLayout());
+	fl_DocSectionLayout * pDSL = static_cast<fl_DocSectionLayout *>(pFL->getSectionLayout());
 	UT_ASSERT(pDSL && (pDSL->getContainerType() == FL_CONTAINER_DOCSECTION));
 	return pDSL;
 }
@@ -349,6 +384,13 @@ void fp_FrameContainer::getBlocksAroundFrame(UT_GenericVector<fl_BlockLayout *>
   fl_BlockLayout * pCurBlock = NULL;
   fp_Line * pCurLine = NULL;
   fp_Container * pCurCon = NULL;
+  if(pPage->countColumnLeaders() == 0)
+  {
+      UT_sint32 iPage = getPreferedPageNo();
+      if(iPage >0)
+	setPreferedPageNo(iPage-1);
+      return;
+  }
   for(iColLeader = 0; iColLeader < pPage->countColumnLeaders(); iColLeader++)
   {
     pCol = pPage->getNthColumnLeader(iColLeader);
@@ -406,7 +448,7 @@ void fp_FrameContainer::getBlocksAroundFrame(UT_GenericVector<fl_BlockLayout *>
 void fp_FrameContainer::_drawLine (const PP_PropertyMap::Line & style,
 								  UT_sint32 left, UT_sint32 top, UT_sint32 right, UT_sint32 bot,GR_Graphics * pGr)
 {
-	GR_Painter painter(getGraphics());
+	GR_Painter painter(pGr);
 
 	if (style.m_t_linestyle == PP_PropertyMap::linestyle_none)
 		return; // do not draw	
@@ -449,11 +491,32 @@ void  fp_FrameContainer::drawBoundaries(dg_DrawArgs * pDA)
 	UT_sint32 iXhigh = iXlow + getFullWidth() ;
 	UT_sint32 iYlow = pDA->yoff - m_iYpad;
 	UT_sint32 iYhigh = iYlow + getFullHeight();
+	GR_Graphics * pG = pDA->pG;
 	if(getPage())
 	{
 		getPage()->expandDamageRect(iXlow,iYlow,getFullWidth(),getFullHeight());
-	}
 
+		//
+		// Only fill to the bottom of the viewed page.
+		//
+		UT_sint32 iFullHeight = getFullHeight();
+		fl_DocSectionLayout * pDSL = getDocSectionLayout();
+		UT_sint32 iMaxHeight = 0;
+		if(!pG->queryProperties(GR_Graphics::DGP_PAPER) && (getView()->getViewMode() != VIEW_PRINT))
+		{
+		        iMaxHeight = pDSL->getActualColumnHeight();
+		}
+		else
+		{
+		        iMaxHeight = getPage()->getHeight();
+		}
+		UT_sint32 iBot = getFullY()+iFullHeight;
+		if(iBot > iMaxHeight)
+		{
+		        iFullHeight = iFullHeight - (iBot-iMaxHeight);
+			iYhigh = iFullHeight;
+		}
+	}
 	_drawLine(m_lineTop,iXlow,iYlow,iXhigh,iYlow,pDA->pG); // top
 	_drawLine(m_lineRight,iXhigh,iYlow,iXhigh,iYhigh,pDA->pG); // right
 	_drawLine(m_lineBottom,iXlow,iYhigh,iXhigh,iYhigh,pDA->pG); // bottom
@@ -475,11 +538,34 @@ void  fp_FrameContainer::drawHandles(dg_DrawArgs * pDA)
 	{
 	     return;
 	}
-
+	if(!getPage())
+	{
+	     return;
+	}
+	//
+	// Only fill to the bottom of the viewed page.
+	//
+	GR_Graphics * pG = pDA->pG;
+	UT_sint32 iFullHeight = getFullHeight();
+	fl_DocSectionLayout * pDSL = getDocSectionLayout();
+	UT_sint32 iMaxHeight = 0;
+	if(!pG->queryProperties(GR_Graphics::DGP_PAPER) && (getView()->getViewMode() != VIEW_PRINT))
+	{
+	    iMaxHeight = pDSL->getActualColumnHeight();
+	}
+	else
+	{
+	    iMaxHeight = getPage()->getHeight();
+	}
+	UT_sint32 iBot = getFullY()+iFullHeight;
+	if(iBot > iMaxHeight)
+	{
+	    iFullHeight = iFullHeight - (iBot-iMaxHeight);
+	}
 	UT_sint32 iXlow = pDA->xoff - m_iXpad;
 	UT_sint32 iYlow = pDA->yoff - m_iYpad;
 
-	UT_Rect box(iXlow + pDA->pG->tlu(2), iYlow + pDA->pG->tlu(2), getFullWidth() - pDA->pG->tlu(4), getFullHeight() - pDA->pG->tlu(4));
+	UT_Rect box(iXlow + pDA->pG->tlu(2), iYlow + pDA->pG->tlu(2), getFullWidth() - pDA->pG->tlu(4), iFullHeight - pDA->pG->tlu(4));
 	getView()->drawSelectionBox(box, true);
 }
 
@@ -546,11 +632,28 @@ void fp_FrameContainer::draw(dg_DrawArgs* pDA)
 
 		UT_sint32 x = pDA->xoff - m_iXpad;
 		UT_sint32 y = pDA->yoff - m_iYpad;
-		if(getPage())
+		getPage()->expandDamageRect(x,y,getFullWidth(),getFullHeight());
+
+		//
+		// Only fill to the bottom of the viewed page.
+		//
+		UT_sint32 iFullHeight = getFullHeight();
+		fl_DocSectionLayout * pDSL = getDocSectionLayout();
+		UT_sint32 iMaxHeight = 0;
+		if(!pG->queryProperties(GR_Graphics::DGP_PAPER) && (pView->getViewMode() != VIEW_PRINT))
 		{
-			getPage()->expandDamageRect(x,y,getFullWidth(),getFullHeight());
+		        iMaxHeight = pDSL->getActualColumnHeight();
 		}
-		getFillType()->Fill(pG,srcX,srcY,x,y,getFullWidth(),getFullHeight());
+		else
+		{
+		        iMaxHeight = getPage()->getHeight();
+		}
+		UT_sint32 iBot = getFullY()+iFullHeight;
+		if(iBot > iMaxHeight)
+		{
+		        iFullHeight = iFullHeight - (iBot-iMaxHeight);
+		}
+		getFillType()->Fill(pG,srcX,srcY,x,y,getFullWidth(),iFullHeight);
 	}
 	UT_uint32 count = countCons();
 	const UT_Rect * pPrevRect = pDA->pG->getClipRect();
