@@ -679,14 +679,6 @@ TR(s.utf8_str()), 0);
 	m_wCheckWhiteTransparent = PtCreateWidget(PtToggleButton, vmiscgroup, n, args);
 	PtAddCallback(m_wCheckWhiteTransparent, Pt_CB_ACTIVATE, s_allowTransparentColor, this);
 
-	/** Colour Selector Options **/
-	n = 0;
-	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ShowSplash,s);
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING,
-	TR(s.utf8_str()), 0);
-	PtWidget_t *check_splash = PtCreateWidget (PtToggleButton, vmiscgroup, n, args);
-
-
 /*
 	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING,
@@ -777,8 +769,6 @@ TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_BiDiOptions ).utf8_str(), 0)
   m_checkbuttonViewHiddenText		= checkbuttonViewHidden;
   m_checkbuttonViewUnprintable	= checkbuttonViewUnprintable;
 
-  m_checkbuttonShowSplash = check_splash;
-
   m_buttonSave					= buttonSave;
   m_buttonDefaults				= buttonDefaults;
   m_buttonApply					= buttonApply;
@@ -828,9 +818,6 @@ PtWidget_t *AP_QNXDialog_Options::_lookupWidget ( tControl id )
 	case id_LIST_DEFAULT_PAGE_SIZE:
 		return m_listDefaultPageSize;
 */
-	case id_SHOWSPLASH:
-		return m_checkbuttonShowSplash;
-
 	case id_CHECK_AUTO_SAVE_FILE:
 		return m_checkbuttonAutoSaveFile;
 
@@ -969,7 +956,6 @@ DEFINE_GET_SET_BOOL(OtherHebrewContextGlyphs);
 
 /* File save options related stuff */
 DEFINE_GET_SET_BOOL(AutoSaveFile);
-DEFINE_GET_SET_BOOL(ShowSplash);
 
 void AP_QNXDialog_Options::_gatherAutoSaveFileExt(UT_String &stRetVal)
 {
