@@ -19,6 +19,10 @@
  * 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <gtk/gtk.h>
 
 #include "ap_Features.h"
@@ -283,7 +287,13 @@ void AP_UnixFrame::_scrollFuncY(void * pData, UT_sint32 yoff, UT_sint32 /*yrange
 			   (static_cast<UT_sint32>(pView->getYScrollOffset()-yoffNew)))));
 	gfloat yoffDisc = static_cast<UT_sint32>(pView->getYScrollOffset()) - dy;
 
+	// We need to block the signal this will send. The setYScrollOffset method
+	// will do the scroll for us. Otherwise we'll scroll back here later!!
+	
+	g_signal_handler_block((gpointer)pFrameImpl->m_pVadj, pFrameImpl->m_iVScrollSignal);
 	gtk_adjustment_set_value(GTK_ADJUSTMENT(pFrameImpl->m_pVadj),yoffNew);
+	g_signal_handler_unblock((gpointer)pFrameImpl->m_pVadj, pFrameImpl->m_iVScrollSignal);
+
 
 	if (pG->tdu(static_cast<UT_sint32>(yoffDisc) - 
 				pView->getYScrollOffset()) != 0)
@@ -324,7 +334,13 @@ void AP_UnixFrame::_scrollFuncX(void * pData, UT_sint32 xoff, UT_sint32 /*xrange
 			   (static_cast<UT_sint32>(pView->getXScrollOffset()-xoffNew)))));
 	gfloat xoffDisc = static_cast<UT_sint32>(pView->getXScrollOffset()) - dx;
 
+
+	// We need to block the signal this will send. The setHScrollOffset method
+	// will do the scroll for us. Otherwise we'll scroll back here later!!
+	
+	g_signal_handler_block((gpointer)pFrameImpl->m_pHadj, pFrameImpl->m_iHScrollSignal);
 	gtk_adjustment_set_value(GTK_ADJUSTMENT(pFrameImpl->m_pHadj),xoffDisc);
+	g_signal_handler_unblock((gpointer)pFrameImpl->m_pHadj, pFrameImpl->m_iHScrollSignal);
 
 	// (this is the calculation for dx again, post rounding)
 	// This may not actually be helpful, because we could still lose if the
@@ -341,7 +357,7 @@ void AP_UnixFrame::translateDocumentToScreen(UT_sint32 &x, UT_sint32 &y)
 
 void AP_UnixFrame::setStatusMessage(const char * szMsg)
 {
-#if !defined (EMBEDDED_TARGET) || defined (EMBEDDED_STATUSBAR)
+#ifdef ENABLE_STATUSBAR
 	if((getFrameMode() == XAP_NormalFrame) && (m_pData))
 	{
 		static_cast<AP_FrameData *>(m_pData)->m_pStatusBar->setStatusMessage(szMsg);
