@@ -128,7 +128,7 @@ BOOL AP_Win32Dialog_Lists::_onInitDialog(HWND hWnd, WPARAM wParam, LPARAM lParam
 		AP_RID_DIALOG_LIST_SPIN_INDENT_ALIGN	// non-UDS_SETBUDDYINT
 	};
 
-	for (i = 0; i < NrElements(rgSpinIDs); ++i)
+	for (i = 0; i < G_N_ELEMENTS(rgSpinIDs); ++i)
 	{
 		HWND hWndSpin = GetDlgItem(hWnd, rgSpinIDs[i]);
 		if (hWndSpin)
@@ -153,26 +153,26 @@ BOOL AP_Win32Dialog_Lists::_onInitDialog(HWND hWnd, WPARAM wParam, LPARAM lParam
 		XAP_String_Id	stringId;
 	} static const rgMapping[] =
 	{
-		AP_RID_DIALOG_LIST_STATIC_TYPE			, AP_STRING_ID_DLG_Lists_Type,
-		AP_RID_DIALOG_LIST_STATIC_STYLE			, AP_STRING_ID_DLG_Lists_Style,
-		AP_RID_DIALOG_LIST_GROUP_CUSTOM			, AP_STRING_ID_DLG_Lists_Customize,
-		AP_RID_DIALOG_LIST_BUTTON_DEFAULT		, AP_STRING_ID_DLG_Lists_SetDefault,
-		AP_RID_DIALOG_LIST_STATIC_FORMAT		, AP_STRING_ID_DLG_Lists_Format,
-		AP_RID_DIALOG_LIST_STATIC_FONT			, AP_STRING_ID_DLG_Lists_Font,
-		AP_RID_DIALOG_LIST_BTN_FONT				, AP_STRING_ID_DLG_Lists_ButtonFont,
-		AP_RID_DIALOG_LIST_STATIC_DECIMAL		, AP_STRING_ID_DLG_Lists_DelimiterString,
-		AP_RID_DIALOG_LIST_STATIC_LEVEL			, AP_STRING_ID_DLG_Lists_Level,
-		AP_RID_DIALOG_LIST_STATIC_START_AT		, AP_STRING_ID_DLG_Lists_Start,
-		AP_RID_DIALOG_LIST_STATIC_LIST_ALIGN	, AP_STRING_ID_DLG_Lists_Align,
-		AP_RID_DIALOG_LIST_STATIC_INDENT_ALIGN	, AP_STRING_ID_DLG_Lists_Indent,
-		AP_RID_DIALOG_LIST_STATIC_PREVIEW		, AP_STRING_ID_DLG_Lists_Preview,
-		AP_RID_DIALOG_LIST_RADIO_START_NEW_LIST	, AP_STRING_ID_DLG_Lists_Start_New,
-		AP_RID_DIALOG_LIST_RADIO_APPLY_TO_CURRENT_LIST, AP_STRING_ID_DLG_Lists_Apply_Current,
-		AP_RID_DIALOG_LIST_RADIO_RESUME_PREV_LIST, AP_STRING_ID_DLG_Lists_Resume,
-		AP_RID_DIALOG_LIST_STATIC_FOLDING, AP_STRING_ID_DLG_Lists_FoldingLevelexp
+		{AP_RID_DIALOG_LIST_STATIC_TYPE			, AP_STRING_ID_DLG_Lists_Type},
+		{AP_RID_DIALOG_LIST_STATIC_STYLE			, AP_STRING_ID_DLG_Lists_Style},
+		{AP_RID_DIALOG_LIST_GROUP_CUSTOM			, AP_STRING_ID_DLG_Lists_Customize},
+		{AP_RID_DIALOG_LIST_BUTTON_DEFAULT		, AP_STRING_ID_DLG_Lists_SetDefault},
+		{AP_RID_DIALOG_LIST_STATIC_FORMAT		, AP_STRING_ID_DLG_Lists_Format},
+		{AP_RID_DIALOG_LIST_STATIC_FONT			, AP_STRING_ID_DLG_Lists_Font},
+		{AP_RID_DIALOG_LIST_BTN_FONT				, AP_STRING_ID_DLG_Lists_ButtonFont},
+		{AP_RID_DIALOG_LIST_STATIC_DECIMAL		, AP_STRING_ID_DLG_Lists_DelimiterString},
+		{AP_RID_DIALOG_LIST_STATIC_LEVEL			, AP_STRING_ID_DLG_Lists_Level},
+		{AP_RID_DIALOG_LIST_STATIC_START_AT		, AP_STRING_ID_DLG_Lists_Start},
+		{AP_RID_DIALOG_LIST_STATIC_LIST_ALIGN	, AP_STRING_ID_DLG_Lists_Align},
+		{AP_RID_DIALOG_LIST_STATIC_INDENT_ALIGN	, AP_STRING_ID_DLG_Lists_Indent},
+		{AP_RID_DIALOG_LIST_STATIC_PREVIEW		, AP_STRING_ID_DLG_Lists_Preview},
+		{AP_RID_DIALOG_LIST_RADIO_START_NEW_LIST	, AP_STRING_ID_DLG_Lists_Start_New},
+		{AP_RID_DIALOG_LIST_RADIO_APPLY_TO_CURRENT_LIST, AP_STRING_ID_DLG_Lists_Apply_Current},
+		{AP_RID_DIALOG_LIST_RADIO_RESUME_PREV_LIST, AP_STRING_ID_DLG_Lists_Resume},
+		{AP_RID_DIALOG_LIST_STATIC_FOLDING, AP_STRING_ID_DLG_Lists_FoldingLevelexp}
 	};
 
-	for (i = 0; i < NrElements(rgMapping); ++i)
+	for (i = 0; i < G_N_ELEMENTS(rgMapping); ++i)
 	{
 		_win32Dialog.setControlText(rgMapping[i].controlId,
 									pSS->getValue(rgMapping[i].stringId));
@@ -247,7 +247,6 @@ BOOL AP_Win32Dialog_Lists::_onCommand(HWND hWnd, WPARAM wParam, LPARAM lParam)
 {
 	const WORD wNotifyCode	= HIWORD(wParam);
 	const WORD wId			= LOWORD(wParam);
-	const HWND hWndCtrl		= (HWND)lParam;
 
 	switch (wId)
 	{
@@ -280,7 +279,7 @@ BOOL AP_Win32Dialog_Lists::_onCommand(HWND hWnd, WPARAM wParam, LPARAM lParam)
 		return 1;
 
 	case IDCANCEL:	// also AP_RID_DIALOG_LIST_BTN_CLOSE
-		_win32Dialog.showWindow(SW_HIDE);
+		destroy ();
 		return 1;
 
 	case AP_RID_DIALOG_LIST_BTN_APPLY:
@@ -399,6 +398,7 @@ void AP_Win32Dialog_Lists::destroy(void)
 		setAnswer(AP_Dialog_Lists::a_QUIT);
 		EndDialog(m_hThisDlg, 0);
 		m_hThisDlg = 0;
+		modeless_cleanup();
 		return;
 	}
 
@@ -621,7 +621,7 @@ void AP_Win32Dialog_Lists::_fillTypeList()
 		AP_STRING_ID_DLG_Lists_Type_numbered
 	};
 
-	for (int i = 0; i < NrElements(rgIDs); ++i)
+	for (int i = 0; i < G_N_ELEMENTS(rgIDs); ++i)
 	{
 		_win32Dialog.addItemToCombo(AP_RID_DIALOG_LIST_COMBO_TYPE,
 									pSS->getValue(rgIDs[i]));
@@ -676,11 +676,11 @@ void AP_Win32Dialog_Lists::_fillStyleList(int iType)
 	{
 		case 1:	// bullet list
 			pIDs = rgBulletIDs;
-			nIDs = NrElements(rgBulletIDs);
+			nIDs = G_N_ELEMENTS(rgBulletIDs);
 			break;
 		case 2:	// numbered list
 			pIDs = rgNumberedIDs;
-			nIDs = NrElements(rgNumberedIDs);
+			nIDs = G_N_ELEMENTS(rgNumberedIDs);
 			break;
 	}
 
@@ -740,7 +740,7 @@ void AP_Win32Dialog_Lists::_fillFoldingList()
 		AP_STRING_ID_DLG_Lists_FoldingLevel4
 	};
 
-	for (int i = 0; i < NrElements(rgIDs); ++i)
+	for (int i = 0; i < G_N_ELEMENTS(rgIDs); ++i)
 	{
 		_win32Dialog.addItemToCombo(AP_RID_DIALOG_LIST_COMBO_FOLDING,
 									pSS->getValue(rgIDs[i]));
@@ -824,7 +824,7 @@ void AP_Win32Dialog_Lists::_resetCustomValues()
 
 void AP_Win32Dialog_Lists::_enableCustomControls(bool bEnable)
 {
-	for (int i = 0; i < NrElements(rgCustomIds); ++i)
+	for (int i = 0; i < G_N_ELEMENTS(rgCustomIds); ++i)
 	{
 		_win32Dialog.enableControl(rgCustomIds[i], bEnable);
 	}
@@ -1109,7 +1109,6 @@ void AP_Win32Dialog_Lists::_selectFont()
 	}
 
 	const gchar* pszFont;
-	bool bDirty = false;
 
 
 	if (pDialog->getChangedFontFamily(&pszFont))
