@@ -34,7 +34,7 @@ enum PSH_PAGES {PG_GENERAL, PG_DOCUMENT, PG_SPELL};
 /*
 	Sheet
 */
-class AP_Win32Dialog_Options_Sheet: public XAP_Win32PropertySheet
+class ABI_EXPORT AP_Win32Dialog_Options_Sheet: public XAP_Win32PropertySheet
 {
 	
 public:	
@@ -56,7 +56,7 @@ private:
 /*
 	Spelling page
 */
-class AP_Win32Dialog_Options_Spelling: public XAP_Win32PropertyPage
+class ABI_EXPORT AP_Win32Dialog_Options_Spelling: public XAP_Win32PropertyPage
 {
 	
 public:		
@@ -82,7 +82,7 @@ private:
 /*
 	General page
 */
-class AP_Win32Dialog_Options_General: public XAP_Win32PropertyPage
+class ABI_EXPORT AP_Win32Dialog_Options_General: public XAP_Win32PropertyPage
 {
 	
 public:		
@@ -109,7 +109,7 @@ private:
 /*
 	Document page
 */
-class AP_Win32Dialog_Options_Document: public XAP_Win32PropertyPage
+class ABI_EXPORT AP_Win32Dialog_Options_Document: public XAP_Win32PropertyPage
 {
 	
 public:	
@@ -136,7 +136,7 @@ private:
 
 
 /*****************************************************************/
-class AP_Win32Dialog_Options: public AP_Dialog_Options
+class ABI_EXPORT AP_Win32Dialog_Options: public AP_Dialog_Options
 {
 public:
 	AP_Win32Dialog_Options(XAP_DialogFactory * pDlgFactory, XAP_Dialog_Id id);
@@ -176,7 +176,6 @@ public:
 	SET_GATHER			(SpellNumbers,		bool );
 	SET_GATHER			(GrammarCheck,		bool); 
 	SET_GATHER			(ViewRulerUnits,	UT_Dimension);
-	SET_GATHER			(ViewCursorBlink,	bool);
 	SET_GATHER			(AllowCustomToolbars, bool);
 	SET_GATHER			(AutoLoadPlugins, bool);
 	SET_GATHER			(OtherDirectionRtl, bool );
@@ -188,6 +187,7 @@ public:
 
 	// unimplemented UI-wise. We need dummy implementations to satisfy the XP framework, though
 
+	SET_GATHER			(ViewCursorBlink,		bool);
 	SET_GATHER			(PrefsAutoSave,			bool);
 	SET_GATHER			(ViewShowRuler,			bool);
 	SET_GATHER			(ViewShowStatusBar,		bool);
@@ -218,6 +218,7 @@ public:
 	bool			m_boolViewShowStatusBar;
 	bool			m_boolViewUnprintable;
 
+	bool			m_boolViewCursorBlink;
 	
 #undef SET_GATHER
 
