@@ -24,6 +24,7 @@
 #include "ut_Win32Timer.h"
 #include "ut_Win32OS.h"
 #include "gr_Win32Graphics.h"
+#include "gr_Painter.h"
 #include "ap_Win32TopRuler.h"
 #include "ap_Win32LeftRuler.h"
 #include "ap_Win32StatusBar.h"
@@ -323,6 +324,11 @@ void AP_Win32FrameImpl::_showOrHideStatusbar(void)
 	pFrame->toggleStatusBar(bShowStatusBar);
 }
 
+void AP_Win32FrameImpl::_hideMenuScroll(bool bHideMenuScroll)
+{
+	UT_ASSERT_HARMLESS(UT_NOT_IMPLEMENTED);
+}
+
 /* helper methods for helper methods for _showDocument (meta-helper-methods?) :-)
  * called by AP_Frame::_replaceView which is called by AP_Frame::_showDocument 
  */
@@ -1339,11 +1345,11 @@ LRESULT CALLBACK AP_Win32FrameImpl::_DocumentWndProc(HWND hwnd, UINT iMsg, WPARA
 			FV_View * pFV = static_cast<FV_View *>(pView);
 			GR_Graphics * pG = pFV->getGraphics();
 
-			GR_CaretDisabler caretDisabler(pG->getCaret());
+			GR_Painter caretDisablerPainter(pG); // not an elegant way to disable all carets, but it works beautifully - MARCM
 			
 			PAINTSTRUCT ps;
 			HDC hdc = BeginPaint(hwnd, &ps);
-
+			UT_return_val_if_fail(hdc, 0);
 			
 			UT_Rect r(pG->tlu(ps.rcPaint.left), pG->tlu(ps.rcPaint.top),
 					pG->tlu(ps.rcPaint.right-ps.rcPaint.left+1),
