@@ -26,6 +26,10 @@
 // ********************************************************************************
 // ********************************************************************************
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ut_assert.h"
 #include "ut_types.h"
 #include "ev_EditBits.h"
@@ -35,7 +39,7 @@
 #include "ap_LoadBindings.h"
 #include "ap_LB_Default.h"
 
-#define DEFLEN(x) UT_uint32 x ## _len = NrElements(x)
+#define DEFLEN(x) UT_uint32 x ## _len = G_N_ELEMENTS(x)
 
 // NOTE: on Win32 we cannot get ALT-TAB (but we can get ALT-F4 :-)
 
@@ -199,7 +203,7 @@ ap_bs_Mouse MouseTable[] =
 	{_CT _B3,	{ "contextText",		"",			"",		"",			"",			""				}},
 	{_CVD _B3,  { "contextText",		"",			"",		"",			"",			""				}},
 	//{_CL _B3,	{ "contextLeftOfText",	"",			"",		"",			"",			""				}},
-#ifndef WITHOUT_SPELL
+#ifdef ENABLE_SPELL
 	{_CM _B3,	{ "contextMisspellText","",			"",		"",			"",			""				}},
 #endif
 	{_CI _B3,	{ "contextImage",		"",			"",		"",			"",			""				}},
@@ -247,6 +251,16 @@ ap_bs_Mouse MouseTable[] =
 	{_CTO _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
 	{_CVD _B4,	{ "scrollWheelMouseUp",		"scrollWheelMouseUp",			"",		"",			"",			""				}},
 	{_CVD _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
+	{_CTC _B4,	{ "scrollWheelMouseUp",		"scrollWheelMouseUp",			"",		"",			"",			""				}},
+	{_CTC _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
+	{_CTO _B4,	{ "scrollWheelMouseUp",		"scrollWheelMouseUp",			"",		"",			"",			""				}},
+	{_CTO _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
+	{_CPO _B4,	{ "scrollWheelMouseUp",		"scrollWheelMouseUp",			"",		"",			"",			""				}},
+	{_CPO _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
+	{_CMA _B4,	{ "scrollWheelMouseUp",		"scrollWheelMouseUp",			"",		"",			"",			""				}},
+	{_CMA _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
+	{_CEM _B4,	{ "scrollWheelMouseUp",		"scrollWheelMouseUp",			"",		"",			"",			""				}},
+	{_CEM _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
 
 
 //  Button-5, Mouse wheel (3 lines down)
@@ -278,6 +292,16 @@ ap_bs_Mouse MouseTable[] =
 	{_CVD _B5 _C,{ "zoomOut",		            "zoomOut",           			"",		"",			"",			""				}},
 	{_CTO _B5,	{ "scrollWheelMouseDown",		"scrollWheelMouseDown",			"",		"",			"",			""				}},
 	{_CTO _B5 _C,{ "zoomOut",		            "zoomOut",           			"",		"",			"",			""				}},
+	{_CTC _B5,	{ "scrollWheelMouseDown",		"scrollWheelMouseDown",			"",		"",			"",			""				}},
+	{_CTC _B5 _C,{ "zoomOut",		            "zoomIn",           			"",		"",			"",			""				}},
+	{_CTO _B5,	{ "scrollWheelMouseDown",		"scrollWheelMouseDown",			"",		"",			"",			""				}},
+	{_CTO _B5 _C,{ "zoomOut",		            "zoomIn",           			"",		"",			"",			""				}},
+	{_CPO _B5,	{ "scrollWheelMouseDown",		"scrollWheelMouseDown",			"",		"",			"",			""				}},
+	{_CPO _B5 _C,{ "zoomOut",		            "zoomIn",           			"",		"",			"",			""				}},
+	{_CMA _B5,	{ "scrollWheelMouseDown",		"scrollWheelMouseDown",			"",		"",			"",			""				}},
+	{_CMA _B5 _C,{ "zoomOut",		            "zoomIn",           			"",		"",			"",			""				}},
+	{_CEM _B5,	{ "scrollWheelMouseDown",		"scrollWheelMouseDown",			"",		"",			"",			""				}},
+	{_CEM _B5 _C,{ "zoomOut",		            "zoomIn",           			"",		"",			"",			""				}},
 
 #if defined(PT_TEST) || defined(FMT_TEST) || defined(UT_TEST)
 //  { context		{ click			doubleclick		drag,		dbldrag,	release,	doublerelease	}},
@@ -310,8 +334,8 @@ ap_bs_NVK NVKTable[] =
 						  "",					"",					"",				""					}},
 	{EV_NVK_SPACE,		{ "insertSpace",		"insertSpace",		"togglePlain",	"insertNBSpace",
 						  "insertNBZWSpace",	"insertZWJoiner",					"",				""					}},
-	{EV_NVK_TAB,		{ "insertTab",			"insertTabShift",					"cycleWindows",	"cycleWindowsBck",
-						  DO_NOT_USE,			"",					"",				""					}},
+	{EV_NVK_TAB,		{ "insertTab",			"insertTabShift",					"insertTabCTL", "cycleWindows",	"cycleWindowsBck",
+						  			"",					"",				""					}},
 	{EV_NVK_RETURN,		{ "insertParagraphBreak", "insertLineBreak", "insertPageBreak", "insertColumnBreak",
 						  "insertSectionBreak",	"",					"",				""					}},
 	{EV_NVK_ESCAPE,		{ "doEscape", "doEscape", "doEscape",  "doEscape","doEscape", "doEscape",  "doEscape", "doEscape" }},
@@ -360,7 +384,7 @@ ap_bs_NVK NVKTable[] =
 #else
 //	{EV_NVK_F6,			{ "",					"",					"",				"",
 //						  "",					"",					"",			""					}},
-#ifndef WITHOUT_SPELL
+#ifdef ENABLE_SPELL
 	{EV_NVK_F7,			{ "dlgSpell",			"",					"",				"",
 						  "",					"",					"",				""					}},
 #endif
