@@ -173,9 +173,9 @@ static void close_gsf_handle(GsfOutput * output)
 /*****************************************************************/
 
 #ifdef ENABLE_RESOURCE_MANAGER
-class s_AbiWord_1_Listener : public PL_Listener, XAP_ResourceManager::Writer
+class ABI_EXPORT s_AbiWord_1_Listener : public PL_Listener, XAP_ResourceManager::Writer
 #else
-class s_AbiWord_1_Listener : public PL_Listener
+class ABI_EXPORT s_AbiWord_1_Listener : public PL_Listener
 #endif
 {
 public:
@@ -568,8 +568,8 @@ void s_AbiWord_1_Listener::_openTag(const char * szPrefix, const char * szSuffix
 				UT_UTF8String_sprintf(sVal,"%fin",dInch);
 				tag += "width:";
 				tag += sVal;
-				tag += "\"";
 			}
+			tag += "\"";
 			tag += "/";
 			tag += ">";
 			tag += "</math";
@@ -621,8 +621,8 @@ void s_AbiWord_1_Listener::_openTag(const char * szPrefix, const char * szSuffix
 				UT_UTF8String_sprintf(sVal,"%fin",dInch);
 				tag += "width:";
 				tag += sVal;
-				tag += "\"";
 			}
+			tag += "\"";
 			tag += "/";
 			tag += ">";
 			tag += "</embed";
@@ -956,9 +956,10 @@ bool s_AbiWord_1_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 		}
 
 	case PX_ChangeRecord::PXT_InsertFmtMark:
-#if 0
-		// fmt marks are temporary placeholders for props and
-		// attributes and should not be saved
+#if 1
+		// This code was commented by tf for reasons we can't remember
+		// Reinstate it to fix bug - 11629 blank lines lose their
+		// properties on export.
 		if(m_bOpenChar)
 			_closeTag();
 		_openTag("c","",false,pcr->getIndexAP(),0);
