@@ -112,7 +112,7 @@ UT_Confidence_t IE_Imp_XHTML_Sniffer::recognizeContents(const char * szBuf,
 	UT_uint32 iLinesToRead = 6 ;  // Only examine the first few lines of the file
 	UT_uint32 iBytesScanned = 0 ;
 	const char *p ;
-	char *magic ;
+	const char *magic ;
 	p = szBuf ;
 	while( iLinesToRead-- )
 	{
@@ -606,7 +606,7 @@ static bool recognizeXHTML (const char * szBuf, UT_uint32 iNumbytes)
 	UT_uint32 iLinesToRead = 6 ;  // Only examine the first few lines of the file
 	UT_uint32 iBytesScanned = 0 ;
 	const char *p ;
-	char *magic ;
+	const char *magic ;
 	p = szBuf ;
 	while( iLinesToRead-- )
 	{
@@ -653,9 +653,9 @@ UT_Error IE_Imp_XHTML::_loadFile(GsfInput * input)
 			{
 				char buf[1024];
 
-				gsf_input_read (input, UT_MIN(size, sizeof(buf)), (guint8*)buf);
+				gsf_input_read (input, std::min(size, static_cast<gsf_off_t>(sizeof(buf))), (guint8*)buf);
 				
-				is_xml = recognizeXHTML (buf, UT_MIN(size, sizeof(buf)));
+				is_xml = recognizeXHTML (buf, std::min(size, static_cast<gsf_off_t>(sizeof(buf))));
 			}
 	}
 
@@ -788,7 +788,12 @@ void IE_Imp_XHTML::startElement(const gchar *name,
 
 	if(m_bInMath && (tokenIndex != TT_MATH))
 	{
-		UT_return_if_fail(m_pMathBB);
+		if(!m_pMathBB)
+		{
+			UT_ASSERT_HARMLESS(m_pMathBB);
+			goto cleanup;
+		}
+
 		m_pMathBB->append(reinterpret_cast<const UT_Byte *>("<"), 1);
 		m_pMathBB->append(reinterpret_cast<const UT_Byte *>(name), strlen(name)); //build the mathml
 		m_pMathBB->append(reinterpret_cast<const UT_Byte *>(">"), 1);
@@ -938,11 +943,16 @@ void IE_Imp_XHTML::startElement(const gchar *name,
 		goto cleanup;
 
 	case TT_PRE:
+	{
 		if (m_parseState == _PS_Block) m_parseState = _PS_Sec;
-		requireBlock ();
+
+		const gchar * style = _getXMLPropValue ("style", atts);
+		newBlock ("Plain Text", style, NULL);
+
 		m_iPreCount++;
 		m_bWhiteSignificant = true;
 		goto cleanup;
+	}
 
 	case TT_H1:
 	case TT_H2:
@@ -1209,7 +1219,6 @@ void IE_Imp_XHTML::startElement(const gchar *name,
 					X_CheckError(appendObject(PTO_Bookmark,bm_new_atts));
 
 					FREEP(m_szBookMarkName);
-					m_szBookMarkName = NULL;
 				}
 			}
 		}
@@ -1239,7 +1248,7 @@ void IE_Imp_XHTML::startElement(const gchar *name,
 
 		if (pfg == 0) break;
 
-		UT_ByteBuf * pBB = static_cast<FG_GraphicRaster *>(pfg)->getRaster_PNG ();
+		const UT_ByteBuf * pBB = static_cast<FG_GraphicRaster *>(pfg)->getRaster_PNG ();
 		X_CheckError(pBB);
 
 		char * mimetype = g_strdup ("image/png");
@@ -1778,6 +1787,7 @@ void IE_Imp_XHTML::endElement(const gchar *name)
 					m_Title.clear();
 				}
 		}
+		return;
 
 	case TT_A:
 		if( m_szBookMarkName )
@@ -1800,7 +1810,6 @@ void IE_Imp_XHTML::endElement(const gchar *name)
 			X_CheckError(appendObject(PTO_Bookmark,bm_new_atts));
 			for(i = 0; i < 5; i++) FREEP(bm_new_atts[i]);
 			FREEP(m_szBookMarkName);
-			m_szBookMarkName = NULL;
 		}
 		else if (m_parseState == _PS_Block)
 		{
@@ -2201,7 +2210,7 @@ bool IE_Imp_XHTML::appendFmt( const gchar ** attributes)
 	return true;
 }
 
-bool IE_Imp_XHTML::appendFmt(const UT_GenericVector<gchar*>* pVecAttributes)
+bool IE_Imp_XHTML::appendFmt(const UT_GenericVector<const gchar*>* pVecAttributes)
 {
 	if(!m_addedPTXSection)
 		{
@@ -2215,12 +2224,13 @@ bool IE_Imp_XHTML::appendFmt(const UT_GenericVector<gchar*>* pVecAttributes)
 		{
 			if(pVecAttributes->getItemCount() >= 2)
 			{
-				gchar * pszProp = pVecAttributes->getNthItem(0);
-				gchar * pszVal = pVecAttributes->getNthItem(1);
+				const gchar * pszProp = pVecAttributes->getNthItem(0);
+				const gchar * pszVal = pVecAttributes->getNthItem(1);
 				if(strcmp(pszProp,"props") == 0 && strlen(pszVal) == 0)
 				{
-					const_cast<UT_GenericVector<gchar*>*>(pVecAttributes)->deleteNthItem(0);
-					const_cast<UT_GenericVector<gchar*>*>(pVecAttributes)->deleteNthItem(0);
+					// FIXME: this is butt ugly !!!!
+					const_cast<UT_GenericVector<const gchar*>*>(pVecAttributes)->deleteNthItem(0);
+					const_cast<UT_GenericVector<const gchar*>*>(pVecAttributes)->deleteNthItem(0);
 				}
 				if(pVecAttributes->getItemCount() == 0)
 				{
@@ -2236,8 +2246,8 @@ bool IE_Imp_XHTML::appendFmt(const UT_GenericVector<gchar*>* pVecAttributes)
 			UT_uint32 i = 0;
 			for(i=0; i< pVecAttributes->getItemCount(); i +=2)
 				{
-					UT_String sProp = static_cast<char *>(pVecAttributes->getNthItem(i));
-					UT_String sVal = static_cast<char *>(pVecAttributes->getNthItem(i));
+					UT_String sProp = pVecAttributes->getNthItem(i);
+					UT_String sVal = pVecAttributes->getNthItem(i);
 					UT_String_setProperty(sPropString,sProp,sVal);
 				}
 			attributes[1] = sPropString.c_str();
@@ -2471,6 +2481,7 @@ static void s_props_append (UT_UTF8String & props, UT_uint32 css_mask,
 							const char * name, char * value)
 {
 	UT_HashColor color;
+	UT_UTF8String sLineHeight;
 
 	const char * verbatim = 0;
 
@@ -2599,6 +2610,16 @@ static void s_props_append (UT_UTF8String & props, UT_uint32 css_mask,
 							verbatim = "subscript";
 						}
 				}
+			else if (strcmp (name, "display") == 0)
+				{
+					if (strcmp (value, "none") == 0)
+						{
+							if (props.byteLength ()) props += "; ";
+							props += name;
+							props += ":";
+							props += value;
+						}
+				}
 			else if ((strcmp (name, "color") == 0) || (strcmp (name, "background") == 0))
 				{
 					/* AbiWord uses rgb hex-sequence w/o the # prefix used by CSS
@@ -2690,6 +2711,29 @@ static void s_props_append (UT_UTF8String & props, UT_uint32 css_mask,
 				{
 					verbatim = value;
 				}
+			else if (strcmp (name, "line-height") == 0)
+				{
+					// examples of handled values: line-height: 1.4,
+					// line-height: 14pt, line-height: 140%
+
+					double d = UT_convertDimensionless (value);
+
+					if (d > 0)
+					{
+						UT_Dimension units = UT_determineDimension (value, DIM_none);
+
+						if (units == DIM_none || units == DIM_PT)
+						{
+							verbatim = value;
+						}
+						else if (units == DIM_PERCENT)
+						{
+							UT_LocaleTransactor t(LC_NUMERIC, "C");
+							sLineHeight = UT_UTF8String_sprintf("%.1f", d/100.0);
+							verbatim = sLineHeight.utf8_str();
+						}
+					}
+				}
 		}
 	if (css_mask & CSS_MASK_IMAGE)
 		{
